<?php
#
# HLstatsX - Real-time player and clan rankings and statistics for Half-Life:Source
# http://www.hlstatsx.com/
# Copyright (C) 2005 Tobias Oetzel (Tobi@hlstatsx.com)
#
# HlstatsX is an enhanced version of HLstats made by Simon Garner
# HLstats - Real-time player and clan rankings and statistics for Half-Life
# http://sourceforge.net/projects/hlstats/
# Copyright (C) 2001  Simon Garner
#             
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#

 require("config.php");

 header("Content-Type: text/html; charset=utf-8");

	// Allows HLstats to work with register_globals Off
	if ( function_exists('ini_get') ) {
		$globals = ini_get('register_globals');
	} else {
		$globals = get_cfg_var('register_globals');
	}
	if ($globals != 1) {
		@extract($_SERVER, EXTR_SKIP);
		@extract($_COOKIE, EXTR_SKIP);
		@extract($_POST, EXTR_SKIP);
		@extract($_GET, EXTR_SKIP);
		@extract($_ENV, EXTR_SKIP);
	}

	// Check PHP configuration

	if (version_compare(phpversion(), "4.1.0", "<"))
	{
		error("HLstats requires PHP version 4.1.0 or newer (you are running PHP version " . phpversion() . ").");
	}

	if (!get_magic_quotes_gpc())
	{
		error("HLstats requires <b>magic_quotes_gpc</b> to be <i>enabled</i>. Check your php.ini or refer to the PHP manual for more information.");
	}

	if (get_magic_quotes_runtime())
	{
		error("HLstats requires <b>magic_quotes_runtime</b> to be <i>disabled</i>. Check your php.ini or refer to the PHP manual for more information.");
	}

	// this doesn't work with php 4.0.3+
	/*if (!ini_get("track_vars"))
	{
		error("HLstats requires <b>track_vars</b> to be <i>enabled</i>. Check your php.ini or refer to the PHP manual for more information.");
	}*/

	// do not report NOTICE warnings
	error_reporting(E_ALL ^ E_NOTICE);


	///
	/// Classes
	///

	// Load database classes
	require(INCLUDE_PATH . "/db.inc");


  // array getOptions (void)
  //
  // Retrieves HLstats option and style settings from the database.
  //

  function getOptions()
  {
    global $db;

    $result  = $db->query("SELECT keyname, value FROM hlstats_Options");
    $numrows = $db->num_rows($result);

    if ($numrows)
    {
        while ($rowdata = $db->fetch_row($result))
        {
            $options[$rowdata[0]] = $rowdata[1];
        }
        return $options;
    }
    else
    {
        error("Warning: Could not find any options in table " .
            "<b>hlstats_Options</b>, database <b>" . DB_NAME . "</b>. Check HLstats configuration.");
        return array();
    }
  }
    

	////
	//// Initialisation
	////

	define("VERSION", "1.00");

	$db_classname = "DB_" . DB_TYPE;
	$db = new $db_classname;

	$g_options = getOptions();

  if (!$g_options["scripturl"])
    $g_options["scripturl"] = $PHP_SELF;


	////
	//// Main
	////
    
    $game = "css";  
    if ((isset($_GET['game'])) && (is_string($_GET['game'])))
      $game = $_GET['game'];
    $width = 180;  
    if ((isset($_GET['width'])) && (is_numeric($_GET['width'])))
      $width = $_GET['width'];
    $server_id = 1;  
    if ((isset($_GET['server_id'])) && (is_numeric($_GET['server_id'])))
      $server_id = $_GET['server_id'];
    $show_logo = 1;
    if ((isset($_GET['show_logo'])) && (is_numeric($_GET['show_logo'])))
      $show_logo = $_GET['show_logo'];
    $show_password = "";  
    if ((isset($_GET['show_password'])) && (is_string($_GET['show_password'])))
      $show_password = $_GET['show_password'];
    $map_image = 1;
    if ((isset($_GET['map_image'])) && (is_numeric($_GET['map_image'])))
      $map_image = $_GET['map_image'];
    $show_summary = 1;
    if ((isset($_GET['show_summary'])) && (is_numeric($_GET['show_summary'])))
      $show_summary = $_GET['show_summary'];
    $show_players = 1;
    if ((isset($_GET['show_players'])) && (is_numeric($_GET['show_players'])))
      $show_players = $_GET['show_players'];
    $show_map_wins = 1;
    if ((isset($_GET['show_map_wins'])) && (is_numeric($_GET['show_map_wins'])))
      $show_map_wins = $_GET['show_map_wins'];
    $top_players = 0;
    if ((isset($_GET['show_top'])) && (is_numeric($_GET['show_top'])))
      $top_players = $_GET['show_top'];
    $background_color = "ABCCD6";  
    if (isset($_GET['bg_color']))
      $background_color = $_GET['bg_color'];
    $body_color = "ECF8FF";  
    if ((isset($_GET['body_color'])) && (is_string($_GET['body_color'])))
      $body_color = $_GET['body_color'];
    $color = "#FFFFFF";  
    if ((isset($_GET['color'])) && (is_string($_GET['color'])))
      $color = $_GET['color'];
      
      
    // entries
    $result  = $db->query("SELECT * FROM hlstats_Servers WHERE serverId='$server_id'");
    $server_data = $db->fetch_array($result);
    
    $result    = $db->query("SELECT eventTime FROM hlstats_Events_Frags WHERE serverId='$server_id' ORDER BY id DESC LIMIT 0,1");
    $last_kill = $db->fetch_array($result);
    
    
    if ($server_data['address'] != "")  {
        
        echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">';
        echo '<html><head><title>HLstatsX</title></head><body style="background:#'.$body_color.'">';

        
        echo '<table border="0" cellpadding="0" cellspacing="0" style="border:1px solid #A8B090;background:#'.$background_color.';color:#'.$color.';width:'.$width.'">';
        if ($show_logo > 0) {
          echo '<tr style="background-image:url('.$g_options['imgdir'].'/title-background.gif);"><td align="center" colspan="3">';
          echo '<a target="_blank" href="http://www.hlstatsx.com" style="display:block;"><img src="'.$g_options['imgdir'].'/title.gif" style="border:0px" alt="Realtime player statistics for Halflife2 Source Engine" title="Realtime player statistics for Halflife2 Source Engine" /></a>';
        } else {   
          echo '<tr style="background-image:url('.$g_options['imgdir'].'/title-background.gif);"><td align="center" colspan="3">';
          echo '<a target="_blank" href="http://www.hlstatsx.com" title="Realtime player statistics for Halflife2 Source Engine" style="color:white;text-decoration:none;"><strong>www.hlstatsx.com<strong></a>';
        }  
        echo '</td></tr>';

        echo '<tr><td align="center" colspan="2">';
        echo '<small><strong><a target="_blank" href="'.$g_options['siteurl'].'" title="'.$g_options['sitename'].'" style="color:#'.$color.';text-decoration:none;">'.$server_data['name'].'</a></strong></small>';
        echo '</td></tr>';
        echo '<tr><td align="center" colspan="2">';
        echo '<small><strong><a href="hlsw://'.$server_data['address'].':'.$server_data['port'].'" title="Watch with HLSW" style="color:#'.$color.';text-decoration:none;">'.$server_data['address'].':'.$server_data['port'].'</a></strong></small>';
        echo '</td></tr>';
        
        if ($show_password != "")  {
        echo '<tr><td align="center" colspan="2">';
        echo '<small><strong>Password:&nbsp;'.$show_password.'</strong></small>';
        echo '</td></tr>';
        }    
        
        if ($map_image == 1) {
          if (file_exists($g_options['imgpath'].'/maps/'.$game.'/'.$server_data['act_map'].'.jpg')) {  
            echo '<tr><td align="center" colspan="2">';
            echo '<a target="_blank" href="'.$g_options['siteurl'].'"><img src="'.$g_options['imgdir'].'/maps/'.$game.'/'.$server_data['act_map'].'.jpg" style="width:'.$width.'px;border:0px" alt="'.$g_options['sitename'].'" title="'.$g_options['sitename'].'" /></a>'; 
            echo '</td></tr>';
          }  
        }
        
        if ($show_summary == 1)  {
          echo '<tr><td align="left">';
          echo '<small style="padding-left:3px">Total Players</small>'; 
          echo '</td><td align="right">';
          echo '<small><strong style="padding-right:3px">'.$server_data['players'].'</strong></small>'; 
          echo '</td></tr>';
    
          echo '<tr><td align="left">';
          echo '<small style="padding-left:3px">Total Kills</small>'; 
          echo '</td><td align="right">';
          echo '<small><strong style="padding-right:3px">'.$server_data['kills'].'</strong></small>'; 
          echo '</td></tr>';
    
          echo '<tr><td align="left">';
          echo '<small style="padding-left:3px">Total Headshots</small>'; 
          echo '</td><td align="right">';
          echo '<small><strong style="padding-right:3px">'.$server_data['headshots'].'</strong></small>'; 
          echo '</td></tr>';

        }    
        
        echo '<tr><td align="left">';
        echo '<small style="padding-left:3px">Map</small>'; 
        echo '</td><td align="right">';
        echo '<small><strong style="padding-right:3px">'.$server_data['act_map'].'</strong></small>'; 
        echo '</td></tr>';
        $stamp = time()-$server_data['map_started'];
        $hours = sprintf("%02d", floor($stamp / 3600));
        $min   = sprintf("%02d", floor(($stamp % 3600) / 60));
        $sec   = sprintf("%02d", floor($stamp % 60)); 
        echo '<tr><td align="left">';
        echo '<small style="padding-left:3px">Map started</small>'; 
        echo '</td><td align="right">';
        echo '<small><strong style="padding-right:3px">'.$hours.':'.$min.':'.$sec.'</strong></small>'; 
        echo '</td></tr>';
        echo '<tr><td align="left">';
        echo '<small style="padding-left:3px">Players</small>'; 
        echo '</td><td align="right">';
        echo '<small><strong style="padding-right:3px">'.$server_data['act_players'].'/'.$server_data['max_players'].'</strong></small>'; 
        echo '</td></tr>';
        
        if ($show_players > 0)  {
            echo '<tr><td colspan="2"><table border="0" cellpadding="0" cellspacing="0" style="padding:0px;margin:0px;width:100%">';
            $players = $db->query("SELECT * FROM hlstats_Livestats WHERE server_id=".$server_id." ORDER BY kills DESC");
            
            $ct_wins      = 0;
            $ct_kills     = 0;
            $ct_deaths    = 0;
            $ct_time      = 0;
            $ct_headshots = 0;
            $ct_pings     = 0;
            $ct_skill     = 0;
            $ct_shots     = 0;
            $ct_hits      = 0;
            
            $ts_wins      = 0;
            $ts_kills     = 0;
            $ts_deaths    = 0;
            $ts_time      = 0;
            $ts_headshots = 0;
            $ts_pings     = 0;
            $ts_skill     = 0;
            $ts_shots     = 0;
            $ts_hits      = 0;
    
            $ct_players = array();
            $ts_players = array();
            $co_players = array();
            while ($pl_rowdata = $db->fetch_array())
            {
                 if ($pl_rowdata['team'] == "CT") {
                   if ($pl_rowdata['connected'] > 0) {
                     $ct_players[] = $pl_rowdata;
                     $ct_kills     += $pl_rowdata['kills'];
                     $ct_deaths    += $pl_rowdata['deaths'];
                     $ct_headshots += $pl_rowdata['headshots'];
                     $ct_pings     += $pl_rowdata['ping'];
                     $ct_skill     += $pl_rowdata['skill'];
                     $ct_shots     += $pl_rowdata['shots']; 
                     $ct_hits      += $pl_rowdata['hits']; 
                     $ct_time      += time()-$pl_rowdata['connected'];
                   } else
                   $co_players[] = $pl_rowdata;  
                 } else if ($pl_rowdata['team'] == "TERRORIST") {
                   if ($pl_rowdata['connected'] > 0) {
                       $ts_players[] = $pl_rowdata;
                     $ts_kills     += $pl_rowdata['kills'];
                     $ts_deaths    += $pl_rowdata['deaths'];
                     $ts_headshots += $pl_rowdata['headshots'];
                     $ts_pings     += $pl_rowdata['ping'];
                     $ts_skill     += $pl_rowdata['skill'];
                     $ts_shots     += $pl_rowdata['shots']; 
                     $ts_hits      += $pl_rowdata['hits']; 
                     $ts_time      += time()-$pl_rowdata['connected'];
                   } else
                   $co_players[] = $pl_rowdata;  
                 } else
                   $co_players[] = $pl_rowdata;  
            }
            $j=0;
            while (isset($ct_players[$j])) {        
              echo '<tr style="background:#D2E8F7;color:#0080C0"><td align="left" width="86%" style="padding-left:3px">';
              if (strlen($ct_players[$j]['name'])>15)
                $ct_players[$j]['name'] = substr($ct_players[$j]['name'], 0, 15);
              echo '<a target="_blank" style="color:#0080C0;text-decoration:none;" href="'.$g_options["siteurl"].'/hlstats.php?mode=playerinfo&amp;player='.$ct_players[$j]['player_id'].'"><small>'.htmlentities($ct_players[$j]['name'], ENT_COMPAT, "UTF-8").'</small></a>';
              echo '</td><td align="right" width="7%" style="padding-right:3px">';
              echo '<small>'.$ct_players[$j]['kills'].'</small>';
              echo '</td><td align="right" width="7%">';
              echo '<small style="padding-right:3px">'.$ct_players[$j]['deaths'].'</small>';
              echo '</td></tr>'; 
              $j++;
            }  
            $j=0;
            while (isset($ts_players[$j])) {        
              echo '<tr style="background:#FFD5D5;color:#FF2D2D;"><td align="left" width="86%" style="padding-left:3px">';
              if (strlen($ts_players[$j]['name'])>15)
                $ts_players[$j]['name'] = substr($ts_players[$j]['name'], 0, 15);
              echo '<a target="_blank" style="color:#FF2D2D;text-decoration:none;" href="'.$g_options["siteurl"].'?mode=playerinfo&amp;player='.$ct_players[$j]['player_id'].'"><small>'.htmlentities($ts_players[$j]['name'], ENT_COMPAT, "UTF-8").'</small></a>';
              echo '</td><td align="right" width="7%" style="padding-right:3px">';
              echo '<small>'.$ts_players[$j]['kills'].'</small>';
              echo '</td><td align="right" width="7%">';
              echo '<small style="padding-right:3px">'.$ts_players[$j]['deaths'].'</small>';
              echo '</td></tr>'; 
              $j++;
            }  
            $j=0;
            while (isset($co_players[$j])) {        
              echo '<tr style="background:#EFEFEF;color:black"><td align="left" width="100%" colspan="3" style="padding-left:3px">';
              if (strlen($co_players[$j]['name'])>15)
                $co_players[$j]['name'] = substr($co_players[$j]['name'], 0, 15);
              echo '<a target="_blank" style="color:black;text-decoration:none;" href="'.$g_options["siteurl"].'?mode=playerinfo&amp;player='.$ct_players[$j]['player_id'].'"><small>'.htmlentities($co_players[$j]['name'], ENT_COMPAT, "UTF-8").'</small></a>';
              echo '</td></tr>'; 
              $j++;
            }  
            if ((count($ct_players)==0) && (count($ts_players)==0) && (count($co_players)==0)) {
              echo '<tr style="background:#EFEFEF;color:black"><td align="left" width="100%" colspan="3" style="padding-left:3px">';
              echo '<small>No Players</small>';
              echo '</td></tr>'; 
            }    
            echo '</table></td></tr>';

        }    
        
        if ($show_map_wins > 0)  {
          echo '<tr><td align="center" colspan="3">';
          echo '<small style="color:#0080C0;font-weight:bold;">CT&nbsp;'.$server_data['map_ct_wins'].'</small>&nbsp;<small style="color:black;">:</small>&nbsp;<small style="color:#FF2D2D;font-weight:bold;">'.$server_data['map_ts_wins'].'&nbsp;TS</small>';
          echo '</td></tr>';
        }
        
        if ($top_players > 0)  {
          $query = "SELECT lastName, skill, IFNULL(kills/deaths, '-') AS kpd, IFNULL(ROUND((hits / shots * 100), 1), 0.0) AS acc, ".
                   "IF(".MINACTIVITY." > (UNIX_TIMESTAMP() - last_event), ((100/".MINACTIVITY.") * (".MINACTIVITY." - (UNIX_TIMESTAMP() - last_event))), 0) as activity ".
                   "FROM hlstats_Players WHERE ".
                   "game='".$game."' AND hideranking=0 ".
                   "HAVING activity > 0 ".
                   "ORDER BY skill DESC, kpd DESC LIMIT 0,".$top_players;
          $players = $db->query($query);
          echo '<tr><td colspan="2"><table border="0" cellpadding="0" cellspacing="0" style="width:100%">';
          echo '<tr><td align="center" colspan="2" style="border-bottom:1px solid black;padding-left:3px">';
          echo '<small><strong>TOP '.$top_players.' Players</small>';
          echo '</td></tr>';
            
          while ($player = $db->fetch_array()) {
            echo '<tr><td align="left" width="85%" style="padding-left:3px">';
            if (strlen($player['lastName']) > 20)
              $player['lastName'] = substr($player['lastName'], 0, 20);
            echo '<a target="_blank" style="color:'.$color.';text-decoration:none;" href="'.$g_options["siteurl"].'/hlstats.php?mode=playerinfo&amp;player='.$ct_players[$j]['player_id'].'"><small>'.htmlentities($player['lastName'], ENT_COMPAT, "UTF-8").'</small></a>';
            echo '</td><td width="15%">';
            echo '<small>'.$player['skill'].'</small>';
            echo '</td></tr>'; 
          }
          echo '</table></td></tr>';
        }       
        
        echo '</table></body></html>';
    }    
    
    

?>

